@@ -3,11 +3,11 @@ from atlassian import Atlassian
 
 class Confluence(Atlassian):
 
-    def create_page(self, space, parent, title, body):
+    def create_page(self, space, parent_id, title, body):
         return self.post("/rest/api/content/", {
             "type": "page",
             "title": title,
-            "ancestors": [{"type": "page", "title": parent}],
+            "ancestors": [{"type": "page", "id": parent_id}],
             "space": {"key": space},
             "body": {"storage": {
                 "value": body,
